@@ -1,28 +1,32 @@
 """
-   SPDX-License-Identifier: GPL-2.0-or-later
+ SPDX-License-Identifier: MIT
 
-   Copyright (C) 2018-2021 SCANOSS LTD
+   Copyright (c) 2021, SCANOSS
 
-   This program is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
-   (at your option) any later version.
+   Permission is hereby granted, free of charge, to any person obtaining a copy
+   of this software and associated documentation files (the "Software"), to deal
+   in the Software without restriction, including without limitation the rights
+   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+   copies of the Software, and to permit persons to whom the Software is
+   furnished to do so, subject to the following conditions:
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   The above copyright notice and this permission notice shall be included in
+   all copies or substantial portions of the Software.
 
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+   THE SOFTWARE.
 
-Winnowing Algorithm implementation for SCANOSS.
+   Winnowing Algorithm implementation for SCANOSS.
 
-This module implements an adaptation of the original winnowing algorithm by S. Schleimer, D. S. Wilkerson and A. Aiken
-as described in their seminal article which can be found here:
-https://theory.stanford.edu/~aiken/publications/papers/sigmod03.pdf
+   This module implements an adaptation of the original winnowing algorithm by S. Schleimer, D. S. Wilkerson and
+   A. Aiken as described in their seminal article which can be found here:
+   https://theory.stanford.edu/~aiken/publications/papers/sigmod03.pdf
 """
-
 import hashlib
 import sys
 
@@ -49,9 +53,9 @@ MIN_FILE_SIZE = 256
 SKIP_SNIPPET_EXT = {  # File extensions to ignore snippets for
                 ".exe", ".zip", ".tar", ".tgz", ".gz", ".7z", ".rar", ".jar", ".war", ".ear", ".class", ".pyc",
                 ".o", ".a", ".so", ".obj", ".dll", ".lib", ".out", ".app", ".bin",
-                ".lst", ".dat", ".json", ".htm", ".html", ".xml",
+                ".lst", ".dat", ".json", ".htm", ".html", ".xml", ".md", ".txt",
                 ".doc", ".docx", ".xls", ".xlsx", ".ppt", ".pptx", ".odt", ".ods", ".odp", ".pages", ".key", ".numbers",
-                ".pdf"
+                ".pdf", ".min.js", ".mf"
 }
 
 class Winnowing:
